==> snaxdart_models-1.0.0.tar.gz: test/v1/app_state_test.dart <==
import 'dart:io';
import 'package:test/test.dart';
import 'dart:convert';

import 'package:snaxdart_models/v1.dart';
import 'package:snaxdart_errors/snaxdart_errors.dart';

void main() {
  group('App State Model', () {
    dynamic appStateString;

    setUp(() {
      appStateString = jsonDecode(
          File('./test/v1/test_data/app_state_test_data.json').readAsStringSync());
    });

    test('should create app state with initial state', () {
      final appState = AppState.initialState();
      final initialWallet = Wallet.initialState();
      expect(appState.wallet, initialWallet);
    });

    test('should create app state copy with wallet', () {
      final wallet = Wallet.fromJson(appStateString['wallet']);
      final appState = AppState(wallet: wallet);

      final newWallet = Wallet(publicKey: null);
      final appStateCopy = appState.copyWith(wallet: newWallet);

      expect(appStateCopy.wallet.publicKey, null);
    });

    test('should create app state copy with global', () {
      final wallet = Wallet.fromJson(appStateString['wallet']);
      final appState = AppState(wallet: wallet);

      final global = Global(walletWasCreated: true);
      final appStateCopy = appState.copyWith(global: global);

      expect(appStateCopy.global.walletWasCreated, true);
    });

    test('should create app state copy with sign up', () {
      final wallet = Wallet.fromJson(appStateString['wallet']);
      final appState = AppState(wallet: wallet);

      final signUp = SignUp(loading: false, error: new GeneralError('Something wrong'));
      final appStateCopy = appState.copyWith(signUp: signUp);

      expect(appStateCopy.signUp.loading, false);
      expect(appStateCopy.signUp.error.message, 'Something wrong');
    });

    test('should create app state copy with transfer', () {
      final wallet = Wallet.fromJson(appStateString['wallet']);
      final appState = AppState(wallet: wallet);

      final transfer = Transfer(loading: false, error: new GeneralError('Something wrong'));

      final appStateCopy = appState.copyWith(transfer: transfer);

      expect(appStateCopy.transfer.loading, false);
      expect(appStateCopy.transfer.error.message, 'Something wrong');
    });

    test('should create app state from json', () {
      final appState = AppState.fromJson(appStateString);

      final expectedWallet = Wallet.fromJson(appStateString['wallet']);

      expect(appState.wallet, expectedWallet);
    });

    test('should create json from app state', () {
      final wallet = Wallet(
          publicKey: 'SNAX78o85K6hKAkszNCo1J9njoGxoicFWdfYsAKdgUqCoQiQTPvfrD');

      final signUp = SignUp();

      final appState = AppState(wallet: wallet, accounts: null);

      final dynamic json = appState.toJson();

      final expectedJson = {
        'wallet': wallet,
        'accounts': null,
        'sign_up': signUp,
        'global': null,
        'transactions': null
      };

      expect(json, expectedJson);
    });
  });
}

==> snaxdart_models-1.1.2.tar.gz: test/v1/app_state_test.dart <==
import 'dart:io';
import 'package:test/test.dart';
import 'dart:convert';

import 'package:snaxdart_models/v1.dart';
import 'package:snaxdart_errors/snaxdart_errors.dart';

void main() {
  group('App State Model', () {
    dynamic appStateString;

    setUp(() {
      appStateString = jsonDecode(
          File('./test/v1/test_data/app_state_test_data.json')
              .readAsStringSync());
    });

    test('should create app state with initial state', () {
      final appState = AppState.initialState();
      final initialWallet = Wallet.initialState();
      expect(appState.wallet, initialWallet);
    });

    test('should create app state copy with wallet', () {
      final wallet = Wallet.fromJson(appStateString['wallet']);
      final appState = AppState(wallet: wallet);

      final newWallet = Wallet(publicKey: null);
      final appStateCopy = appState.copyWith(wallet: newWallet);

      expect(appStateCopy.wallet.publicKey, null);
    });

    test('should create app state copy with global', () {
      final wallet = Wallet.fromJson(appStateString['wallet']);
      final appState = AppState(wallet: wallet);

      final global = Global(walletWasCreated: true);
      final appStateCopy = appState.copyWith(global: global);

      expect(appStateCopy.global.walletWasCreated, true);
    });

    test('should create app state copy with sign up', () {
      final wallet = Wallet.fromJson(appStateString['wallet']);
      final appState = AppState(wallet: wallet);

      final signUp =
          SignUp(loading: false, error: new GeneralError('Something wrong'));
      final appStateCopy = appState.copyWith(signUp: signUp);

      expect(appStateCopy.signUp.loading, false);
      expect(appStateCopy.signUp.error.message, 'Something wrong');
    });

    test('should create app state copy with transfer', () {
      final wallet = Wallet.fromJson(appStateString['wallet']);
      final appState = AppState(wallet: wallet);

      final transfer =
          Transfer(loading: false, error: new GeneralError('Something wrong'));

      final appStateCopy = appState.copyWith(transfer: transfer);

      expect(appStateCopy.transfer.loading, false);
      expect(appStateCopy.transfer.error.message, 'Something wrong');
    });

    test('should create app state from json', () {
      final appState = AppState.fromJson(appStateString);

      final expectedWallet = Wallet.fromJson(appStateString['wallet']);

      expect(appState.wallet, expectedWallet);
    });

    test('should create json from app state', () {
      final wallet = Wallet(
          publicKey: 'SNAX78o85K6hKAkszNCo1J9njoGxoicFWdfYsAKdgUqCoQiQTPvfrD');

      final signUp = SignUp();

      final appState = AppState(wallet: wallet, accounts: null);

      final dynamic json = appState.toJson();

      final expectedJson = {
        'wallet': wallet,
        'accounts': null,
        'sign_up': signUp,
        'global': null,
        'transactions': null
      };

      expect(json, expectedJson);
    });
  });
}
